function [percentJL,percentF]=Comp_JL_F_Leg(n,m,delta)
%COMP_JL_F_LEG comparison of JL-projection and F-projection
%   [percentJL,percentF]=COMP_JL_F_LEG(n,m,delta) computes the percentages of
%   distances preserved but for a relative error between 1-delta and 1+delta by the
%   JL-projection and by the F-projection when project the first n normalised
%   Legendre polynomials from [0,1] to R. It is based on the theory to calculate
%   the percentage relative to the F-projection.
%   INPUT:
%    n: number of normalised Legendre polynomials (1x1)
%    m: dimension of the arrival space (1x1)
%    delta: precision (1x1)
%   OUTPUT:
%    percentJL: percentage of distances preserved by JL (1x1)
%    percentF: percentage of distances preserved by F (1x1)

numJL=0;
numF=0;
J=JL_inf_Leg(n,m);
for i=1:n-1
    for j=i+1:n
        numJL=numJL+(abs(norm(J(:,i)-J(:,j))/sqrt(2)-1)<=delta);
    end
end
if delta>=(sqrt(2)-1)/sqrt(2)
    numF=m*(m-1)/2+m*(n-m);
else
    numF=m*(m-1)/2;
end
percentJL=200*numJL/(n*(n-1));
percentF=200*numF/(n*(n-1));
end
