function pres=JL(n,d,m,delta)
%JL number of JL-projections that almost preserve all distances.
%   pres=JL(n,d,m,delta) computes how many random projections preserve all the
%   n(n-1)/2 distances between n random vectors of dimension d, but for a relative
%   error between 1-delta and 1+delta, when project in dimension m.
%   INPUT:
%    n: number of random vectors (1x1)
%    d: dimension of the initial space (1x1)
%    m: dimension of the arrival space (1x1)
%    delta: precision (1x1)
%   OUTPUT:
%    pres: number of JL-projections that almost preserve all the distances (1x1)

pres=0;
B=rand(d,n);
for k=1:100
    P=randn(m,d)/sqrt(m);
    J=P*B;
    num=0;
    for i=1:n-1
        for j=i+1:n
            num=num+(abs(norm(J(:,i)-J(:,j))/norm(B(:,i)-B(:,j))-1)<=delta);
        end
    end
    if num==n*(n-1)/2
        pres=pres+1;
    end
end
