function J=JL_inf_Leg(n,m)
%JL_INF_LEG infinite JL for normalised Legendre polynomials.
%   J=JL_INF_LEG(n,m) maps in R^m via the JL-projection the first n normalised
%   Legendre polynomials from [0,1] to R.
%   INPUT:
%    n: number of normalised Legendre polynomials (1x1)
%    m: dimension of the arrival space (1x1)
%   OUTPUT:
%    J: matrix with projections as columns (mxn)

B=zeros(n-1,n);
for j=1:n-1
    B(j,j+1)=-sqrt(j/(j+1));
    B(j,1:j)=1/sqrt(j*(j+1));
end
J=randn(m,n-1)*B/sqrt(m);
end